@@ -4,40 +4,42 @@ Utility functions to load libgmt as ctypes.CDLL.
 The path to the shared library can be found automatically by ctypes or set through the
 GMT_LIBRARY_PATH environment variable.
 """
+
 import ctypes
 import os
 import shutil
 import subprocess as sp
 import sys
+from collections.abc import Iterator, Mapping
 from ctypes.util import find_library
 from pathlib import Path
 
 from pygmt.exceptions import GMTCLibError, GMTCLibNotFoundError, GMTOSError
 
 
-def load_libgmt(lib_fullnames=None):
+def load_libgmt(lib_fullnames: Iterator[str] | None = None) -> ctypes.CDLL:
     """
     Find and load ``libgmt`` as a :py:class:`ctypes.CDLL`.
 
     Will look for the GMT shared library in the directories determined by
-    clib_full_names().
+    ``clib_full_names()``.
 
     Parameters
     ----------
-    lib_fullnames : list of str or None
-        List of possible full names of GMT's shared library. If ``None``, will
-        default to ``clib_full_names()``.
+    lib_fullnames
+        List of possible full names of GMT's shared library. If ``None``, will default
+        to ``clib_full_names()``.
 
     Returns
     -------
-    :py:class:`ctypes.CDLL` object
+    libgmt
         The loaded shared library.
 
     Raises
     ------
     GMTCLibNotFoundError
-        If there was any problem loading the library (couldn't find it or
-        couldn't access the functions).
+        If there was any problem loading the library (couldn't find it or couldn't
+        access the functions).
     """
     if lib_fullnames is None:
         lib_fullnames = clib_full_names()
@@ -62,45 +64,60 @@ def load_libgmt(lib_fullnames=None):
     return libgmt
 
 
-def clib_names(os_name):
+def clib_names(os_name: str) -> list[str]:
     """
-    Return the name of GMT's shared library for the current OS.
+    Return the name(s) of GMT's shared library for the current operating system.
 
     Parameters
     ----------
-    os_name : str
+    os_name
         The operating system name as given by ``sys.platform``.
 
     Returns
     -------
-    libnames : list of str
+    libnames
         List of possible names of GMT's shared library.
+
+    Raises
+    ------
+    GMTOSError
+        If the operating system is not supported yet.
     """
-    if os_name.startswith(("linux", "freebsd")):
-        libnames = ["libgmt.so"]
-    elif os_name == "darwin":  # Darwin is macOS
-        libnames = ["libgmt.dylib"]
-    elif os_name == "win32":
-        libnames = ["gmt.dll", "gmt_w64.dll", "gmt_w32.dll"]
-    else:
-        raise GMTOSError(f"Operating system '{os_name}' not supported.")
+    match os_name:
+        case "linux":  # Linux
+            libnames = ["libgmt.so"]
+        case "darwin":  # macOS
+            libnames = ["libgmt.dylib"]
+        case "win32":  # Windows
+            libnames = ["gmt.dll", "gmt_w64.dll", "gmt_w32.dll"]
+        case name if name.startswith("freebsd"):  # FreeBSD
+            libnames = ["libgmt.so"]
+        case _:
+            raise GMTOSError(f"Operating system '{os_name}' is not supported.")
     return libnames
 
 
-def clib_full_names(env=None):
+def clib_full_names(env: Mapping | None = None) -> Iterator[str]:
     """
-    Return the full path of GMT's shared library for the current OS.
+    Return full path(s) of GMT shared library for the current operating system.
+
+    The GMT shared library is searched for in following ways, sorted by priority:
+
+    1. Path defined by environmental variable GMT_LIBRARY_PATH
+    2. Path returned by command "gmt --show-library"
+    3. Path defined by environmental variable PATH (Windows only)
+    4. System default search path
 
     Parameters
     ----------
-    env : dict or None
-        A dictionary containing the environment variables. If ``None``, will
-        default to ``os.environ``.
+    env
+        A dictionary containing the environment variables. If ``None``, will default to
+        ``os.environ``.
 
     Yields
     ------
-    lib_fullnames: list of str
-        List of possible full names of GMT's shared library.
+    lib_fullnames
+        List of possible full names of GMT shared library.
     """
     if env is None:
         env = os.environ
@@ -109,21 +126,18 @@ def clib_full_names(env=None):
 
     # Search for the library in different ways, sorted by priority.
     # 1. Search for the library in GMT_LIBRARY_PATH if defined.
-    libpath = env.get("GMT_LIBRARY_PATH", "")  # e.g. $HOME/miniconda/envs/pygmt/lib
-    if libpath:
+    if libpath := env.get("GMT_LIBRARY_PATH"):  # e.g. $HOME/miniconda/envs/pygmt/lib
         for libname in libnames:
             libfullpath = Path(libpath) / libname
             if libfullpath.exists():
                 yield str(libfullpath)
 
-    # 2. Search for the library returned by command "gmt --show-library"
-    #    Use `str(Path(realpath))` to avoid mixture of separators "\\" and "/"
-    if (gmtbin := shutil.which("gmt")) is not None:
+    # 2. Search for the library returned by command "gmt --show-library".
+    #    Use `str(Path(realpath))` to avoid mixture of separators "\\" and "/".
+    if gmtbin := shutil.which("gmt"):
         try:
             libfullpath = Path(
-                sp.check_output([gmtbin, "--show-library"], encoding="utf-8").rstrip(
-                    "\n"
-                )
+                sp.check_output([gmtbin, "--show-library"], encoding="utf-8").rstrip()
             )
             if libfullpath.exists():
                 yield str(libfullpath)
@@ -133,8 +147,7 @@ def clib_full_names(env=None):
     # 3. Search for DLLs in PATH by calling find_library() (Windows only)
     if sys.platform == "win32":
         for libname in libnames:
-            libfullpath = find_library(libname)
-            if libfullpath:
+            if libfullpath := find_library(libname):
                 yield libfullpath
 
     # 4. Search for library names in the system default path
@@ -142,32 +155,29 @@ def clib_full_names(env=None):
         yield libname
 
 
-def check_libgmt(libgmt):
+def check_libgmt(libgmt: ctypes.CDLL):
     """
-    Make sure that libgmt was loaded correctly.
+    Make sure the GMT shared library was loaded correctly.
 
-    Checks if it defines some common required functions.
-
-    Does nothing if everything is fine. Raises an exception if any of the
-    functions are missing.
+    Checks if the GMT shared library defines a few of the required functions. Does
+    nothing if everything is fine. Raises an exception if any of the functions are
+    missing.
 
     Parameters
     ----------
-    libgmt : :py:class:`ctypes.CDLL`
+    libgmt
         A shared library loaded using ctypes.
 
     Raises
     ------
     GMTCLibError
     """
-    # Check if a few of the functions we need are in the library
-    functions = ["Create_Session", "Get_Enum", "Call_Module", "Destroy_Session"]
-    for func in functions:
+    for func in ["Create_Session", "Get_Enum", "Call_Module", "Destroy_Session"]:
         if not hasattr(libgmt, "GMT_" + func):
             msg = (
                 f"Error loading '{libgmt._name}'. Couldn't access function GMT_{func}. "
-                "Ensure that you have installed an up-to-date GMT version 6 library. "
-                "Please set the environment variable 'GMT_LIBRARY_PATH' to the "
-                "directory of the GMT 6 library."
+                "Ensure that you have installed an up-to-date GMT version 6 library and "
+                "set the environment variable 'GMT_LIBRARY_PATH' to the directory of "
+                "the GMT 6 library."
             )
             raise GMTCLibError(msg)
