@@ -4,6 +4,7 @@ and load as :class:`xarray.DataArray`.
 
 The grids are available in various resolutions.
 """
+
 from typing import Literal
 
 from pygmt.datasets.load_remote_dataset import _load_remote_dataset
@@ -99,8 +100,8 @@ def load_earth_age(
     ... )
     """
     grid = _load_remote_dataset(
-        dataset_name="earth_age",
-        dataset_prefix="earth_age_",
+        name="earth_age",
+        prefix="earth_age",
         resolution=resolution,
         region=region,
         registration=registration,
