@@ -1,10 +1,11 @@
 """
 Helper functions for testing.
 """
+
 import importlib
 import inspect
-import os
 import string
+from pathlib import Path
 
 from pygmt.exceptions import GMTImageComparisonFailure
 from pygmt.io import load_dataarray
@@ -38,6 +39,7 @@ def check_figures_equal(*, extensions=("png",), tol=0.0, result_dir="result_imag
     >>> import pytest
     >>> import shutil
     >>> from pygmt import Figure
+    >>> from pathlib import Path
 
     >>> @check_figures_equal(result_dir="tmp_result_images")
     ... def test_check_figures_equal():
@@ -49,7 +51,7 @@ def check_figures_equal(*, extensions=("png",), tol=0.0, result_dir="result_imag
     ...     )
     ...     return fig_ref, fig_test
     >>> test_check_figures_equal()
-    >>> assert len(os.listdir("tmp_result_images")) == 0
+    >>> assert len(list(Path("tmp_result_images").iterdir())) == 0
     >>> shutil.rmtree(path="tmp_result_images")  # cleanup folder if tests pass
 
     >>> @check_figures_equal(result_dir="tmp_result_images")
@@ -62,12 +64,9 @@ def check_figures_equal(*, extensions=("png",), tol=0.0, result_dir="result_imag
     >>> with pytest.raises(GMTImageComparisonFailure):
     ...     test_check_figures_unequal()
     >>> for suffix in ["", "-expected", "-failed-diff"]:
-    ...     assert os.path.exists(
-    ...         os.path.join(
-    ...             "tmp_result_images",
-    ...             f"test_check_figures_unequal{suffix}.png",
-    ...         )
-    ...     )
+    ...     assert (
+    ...         Path("tmp_result_images") / f"test_check_figures_unequal{suffix}.png"
+    ...     ).exists()
     >>> shutil.rmtree(path="tmp_result_images")  # cleanup folder if tests pass
     """
     allowed_chars = set(string.digits + string.ascii_letters + "_-[]()")
@@ -77,7 +76,7 @@ def check_figures_equal(*, extensions=("png",), tol=0.0, result_dir="result_imag
         import pytest
         from matplotlib.testing.compare import compare_images
 
-        os.makedirs(result_dir, exist_ok=True)
+        Path(result_dir).mkdir(parents=True, exist_ok=True)
         old_sig = inspect.signature(func)
 
         @pytest.mark.parametrize("ext", extensions)
@@ -92,8 +91,8 @@ def check_figures_equal(*, extensions=("png",), tol=0.0, result_dir="result_imag
                 file_name = func.__name__
             try:
                 fig_ref, fig_test = func(*args, **kwargs)
-                ref_image_path = os.path.join(result_dir, f"{file_name}-expected.{ext}")
-                test_image_path = os.path.join(result_dir, f"{file_name}.{ext}")
+                ref_image_path = Path(result_dir) / f"{file_name}-expected.{ext}"
+                test_image_path = Path(result_dir) / f"{file_name}.{ext}"
                 fig_ref.savefig(ref_image_path)
                 fig_test.savefig(test_image_path)
 
@@ -106,11 +105,11 @@ def check_figures_equal(*, extensions=("png",), tol=0.0, result_dir="result_imag
                     in_decorator=True,
                 )
                 if err is None:  # Images are the same
-                    os.remove(ref_image_path)
-                    os.remove(test_image_path)
+                    ref_image_path.unlink()
+                    test_image_path.unlink()
                 else:  # Images are not the same
                     for key in ["actual", "expected", "diff"]:
-                        err[key] = os.path.relpath(err[key])
+                        err[key] = Path(err[key]).relative_to(".")
                     raise GMTImageComparisonFailure(
                         f"images not close (RMS {err['rms']:.3f}):\n"
                         f"\t{err['actual']}\n"
