@@ -1,6 +1,7 @@
 """
 Modern mode session management modules.
 """
+
 import os
 import sys
 
@@ -22,9 +23,9 @@ def begin():
 
     prefix = "pygmt-session"
     with Session() as lib:
-        lib.call_module(module="begin", args=prefix)
+        lib.call_module(module="begin", args=[prefix])
         # pygmt relies on GMT modern mode with GMT_COMPATIBILITY at version 6
-        lib.call_module(module="set", args="GMT_COMPATIBILITY 6")
+        lib.call_module(module="set", args=["GMT_COMPATIBILITY=6"])
 
 
 def end():
@@ -37,4 +38,4 @@ def end():
     ``pygmt.begin``), and bring the figures to the working directory.
     """
     with Session() as lib:
-        lib.call_module(module="end", args="")
+        lib.call_module(module="end", args=[])
