@@ -1,8 +1,9 @@
 """
 image - Plot an image.
 """
+
 from pygmt.clib import Session
-from pygmt.helpers import build_arg_string, fmt_docstring, kwargs_to_strings, use_alias
+from pygmt.helpers import build_arg_list, fmt_docstring, kwargs_to_strings, use_alias
 
 
 @fmt_docstring
@@ -68,4 +69,4 @@ def image(self, imagefile, **kwargs):
     """
     kwargs = self._preprocess(**kwargs)
     with Session() as lib:
-        lib.call_module(module="image", args=build_arg_string(kwargs, infile=imagefile))
+        lib.call_module(module="image", args=build_arg_list(kwargs, infile=imagefile))
