@@ -1,11 +1,12 @@
 """
 info - Get information about data tables.
 """
+
 import numpy as np
 from pygmt.clib import Session
 from pygmt.helpers import (
     GMTTempFile,
-    build_arg_string,
+    build_arg_list,
     fmt_docstring,
     kwargs_to_strings,
     use_alias,
@@ -80,12 +81,11 @@ def info(data, **kwargs):
         - str if none of the above parameters are used.
     """
     with Session() as lib:
-        file_context = lib.virtualfile_from_data(check_kind="vector", data=data)
         with GMTTempFile() as tmpfile:
-            with file_context as fname:
+            with lib.virtualfile_in(check_kind="vector", data=data) as vintbl:
                 lib.call_module(
                     module="info",
-                    args=build_arg_string(kwargs, infile=fname, outfile=tmpfile.name),
+                    args=build_arg_list(kwargs, infile=vintbl, outfile=tmpfile.name),
                 )
             result = tmpfile.read()
 
