@@ -4,8 +4,7 @@ rose - Plot windrose diagrams or polar histograms.
 
 from pygmt.clib import Session
 from pygmt.helpers import (
-    build_arg_string,
-    deprecate_parameter,
+    build_arg_list,
     fmt_docstring,
     kwargs_to_strings,
     use_alias,
@@ -13,7 +12,6 @@ from pygmt.helpers import (
 
 
 @fmt_docstring
-@deprecate_parameter("color", "fill", "v0.8.0", remove_version="v0.12.0")
 @use_alias(
     A="sector",
     B="frame",
@@ -202,9 +200,7 @@ def rose(self, data=None, length=None, azimuth=None, **kwargs):
     kwargs = self._preprocess(**kwargs)
 
     with Session() as lib:
-        file_context = lib.virtualfile_from_data(
+        with lib.virtualfile_in(
             check_kind="vector", data=data, x=length, y=azimuth
-        )
-
-        with file_context as fname:
-            lib.call_module(module="rose", args=build_arg_string(kwargs, infile=fname))
+        ) as vintbl:
+            lib.call_module(module="rose", args=build_arg_list(kwargs, infile=vintbl))
